<?php
/**
 * Newsletter Discounts 
 * Version 2.0 
 * By Scott Wilson - That Software Guy (swguy) 
 * @copyright That Software Guy (www.thatsoftwareguy.com) 
 * @copyright Portions Copyright 2004-2006 Zen Cart Team
 * @copyright Portions Copyright 2003 osCommerce
 * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 */

  class ot_newsletter_discount {
    var $title, $output;
    var $explanation; 

    function ot_newsletter_discount() {
      $this->code = 'ot_newsletter_discount';
      $this->title = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_TITLE;
      $this->description = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_DESCRIPTION;
      $this->sort_order = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_SORT_ORDER;
      $this->include_shipping = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_INC_SHIPPING;
      $this->include_tax = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_INC_TAX;
      $this->calculate_tax = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_CALC_TAX;
      $this->nltype = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_NLTYPE;
      $this->discount_amount = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_AMOUNT; 
      $this->api_key = MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_MAILCHIMP_API_KEY; 
      $this->credit_class = true;
      $this->output = array();
    }

    function print_amount($amount) {
      global $db, $order, $currencies;
      return  $currencies->format($amount, true, $order->info['currency'], $order->info['currency_value']);
    }


    function process() {
       global $db, $order, $currencies;
       if (!$this->is_subscriber()) { 
             return; 
       }
       $od_amount = $this->calculate_deductions();
       if ($od_amount['total'] > 0) {
         reset($order->info['tax_groups']);
         while (list($key, $value) = each($order->info['tax_groups'])) {
           $tax_rate = zen_get_tax_rate_from_desc($key);
           if ($od_amount[$key]) {
             $order->info['tax_groups'][$key] -= $od_amount[$key];
             $order->info['total'] -=  $od_amount[$key];
           }
         }
         $order->info['total'] = $order->info['total'] - $od_amount['total'];
         $this->output[] = array('title' => $this->title . ':',
         'text' => '-' . $currencies->format($od_amount['total'], true, $order->info['currency'], $order->info['currency_value']),
         'value' => $od_amount['total']);
   
       }
    }

    // Add categories you wish to exclude to this list.
    // Go to Admin->Catalog->Categories/Products and look 
    // at the left hand side of the list to determine 
    // category id.   Note that 99999 and 99998 are just given
    // as examples.
    function exclude_category($category) {
        switch($category) {
           case 99999:
           case 99998:
                return true;
        }
        return false;
    }

    // Add products you wish to exclude to this list.
    // Go to Admin->Catalog->Categories/Products->[Your category]
    // and look at the left hand side of the list to determine 
    // product id.   Note that 99999 and 99998 are just given
    // as examples.
    function exclude_product($id) {
        switch($id) {
           case 99999:
           case 99998:
                return true;
        }
        return false;
    }

    function get_order_total() {
		global $order;
		$order_total = 0;

        $products = $_SESSION['cart']->get_products();
        for ($i=0, $n=sizeof($products); $i<$n; $i++) {
           // Add categories you wish to exclude to exclude_category()
           if ($this->exclude_category($products[$i]['category'])) {
               continue; 
           }
           // Add products you wish to exclude to exclude_product()
           if ($this->exclude_product($products[$i]['id'])) {
               continue; 
           }
           $price = $products[$i]['final_price'];
           $quantity = $products[$i]['quantity'];
           $order_total += ($price * $quantity);
        }
		if ($this->include_tax == 'true') $order_total += $order->info['tax'];
		if ($this->include_shipping == 'true') $order_total += $order->info['shipping_cost'];

		return $order_total;
    }

    function calculate_deductions() {
       global $db, $order, $currencies;
       $od_amount = array();
       if (!$this->is_subscriber()) { 
             return $od_amount;
       }
 
       $od_amount['tax'] = 0;

       $order_total = $this->get_order_total(); 
       $disc_amount = $this->discount_amount;
       $this_discount = $order_total * $disc_amount / 100;
       if ($this_discount > $order_total)  {
             $this_discount = $order_total;
       }
       $this_discount_inc_tax = $this_discount; 
       if ($this->include_tax == 'true') {
             $this_discount_inc_tax = $this->gross_up($this_discount); 
       }

       $discount =  $this_discount_inc_tax;

       $od_amount['total'] = round($discount, 2); 
       switch ($this->calculate_tax) {
       case 'Standard':
          reset($order->info['tax_groups']);
          while (list($key, $value) = each($order->info['tax_groups']))
          {
             $tax_rate = zen_get_tax_rate_from_desc($key);
             if ($tax_rate > 0) {
                $od_amount[$key] = $tod_amount = round((($od_amount['total'] * $tax_rate)) /100, 2) ;
                $od_amount['tax'] += $tod_amount;
             }
          }
          break;
      }
      return $od_amount;
   }

   function gross_up($net) {
      global $order;
      $gross_up_amt = 0; 
      reset($order->info['tax_groups']);
      while (list($key, $value) = each($order->info['tax_groups']))
      {
          $tax_rate = zen_get_tax_rate_from_desc($key);
          if ($tax_rate > 0) {
             $gross_up_amt += round((($net * $tax_rate)) /100, 2) ;
          }
      }
      return $gross_up_amt + $net; 
   }

   function pre_confirmation_check($order_total) {
      $od_amount = $this->calculate_deductions();
      return $od_amount['total'] + $od_amount['tax'];
    }

    function credit_selection() {
      return $selection;
    }

    function collect_posts() {
    }

    function update_credit_account($i) {
    }

    function apply_credit() {
    }

    function is_subscriber() {
       global $db, $order;
       if ($this->nltype == 'zencart') {
          $newsletter_query = $db->Execute("select customers_newsletter from " . TABLE_CUSTOMERS . " where customers_id = '" . (int)$_SESSION['customer_id'] . "'");
          if ($newsletter_query->fields['customers_newsletter'] != '0') {
              return true;
          }
       } else {
          $email = array(); 
          $email[] = $order->customer['email_address']; 
          include_once(DIR_WS_CLASSES . "MCAPI.class.php");
          $api = new MCAPI($this->api_key);
          $lists = $api->lists(); 
          $idlist = array(); 
          foreach ($lists['data'] as $list) { 
              $idlist[] = $list['id']; 
          }
          foreach ($idlist as $id) { 
             $info = $api->listMemberInfo($id, $email);
             if ($info == null) continue; 
             if ($info['success'] != 1) continue; 
             if ($info['data'][0]['status'] == 'subscribed') {
                 return true;
             }
          }
       }
       return false;
    }

    function check() {
      global $db;
      if (!isset($this->_check)) {
        $check_query = $db->Execute("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_STATUS'");
        $this->_check = $check_query->RecordCount();
      }

      return $this->_check;
    }

    function keys() {
      return array('MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_STATUS', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_SORT_ORDER', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_INC_SHIPPING', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_INC_TAX', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_CALC_TAX', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_NLTYPE', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_AMOUNT', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_MAILCHIMP_API_KEY');
    }

    function install() {
      global $db;
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('This module is installed', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_STATUS', 'true', '', '6', '1','zen_cfg_select_option(array(\'true\'), ', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Sort Order', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_SORT_ORDER', '285', 'Sort order of display.', '6', '2', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function ,date_added) values ('Include Shipping', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_INC_SHIPPING', 'false', 'Include Shipping in calculation.', '6', '5','zen_cfg_select_option(array(\'true\', \'false\'), ', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function ,date_added) values ('Include Tax', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_INC_TAX', 'false', 'Include Tax in calculation.', '6', '6','zen_cfg_select_option(array(\'true\', \'false\'), ', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function ,date_added) values ('Re-calculate Tax', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_CALC_TAX', 'Standard', 'Re-Calculate Tax', '6', '7','zen_cfg_select_option(array(\'None\', \'Standard\'), ', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function ,date_added) values ('Newsletter Type', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_NLTYPE', 'zencart', 'Are you using a Zen Cart or MailChimp newsletter?', '6', '9', 'zen_cfg_select_option(array(\'zencart\', \'mailchimp\'), ', now())");
      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Discount Amount', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_AMOUNT', '10', 'Percent off', '6', '10', now())");

      $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('MailChimp API Key', 'MODULE_ORDER_TOTAL_NEWSLETTER_DISCOUNT_MAILCHIMP_API_KEY', '', 'MailChimp Newsletters - MailChimp API key', '6', '12', now())");
    } 

    function remove() {
      global $db;
      $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function get_html_policy() {
        $h_exp .= NEWSLETTER_DISCOUNT .  $this->discount_amount . NEWSLETTER_DISCOUNT2;
        return $h_exp; 
    }

  }
?>
